@@ -43,6 +43,8 @@
 #undef GTEST_HAS_TYPED_TEST
 #undef GTEST_HAS_TYPED_TEST_P
 
+#undef GTEST_CAN_STREAM_RESULTS_
+
 #undef GTEST_HAS_EXCEPTIONS
 #undef GTEST_HAS_RTTI
 #undef GTEST_HAS_SEH
@@ -60,6 +62,8 @@
 #define GTEST_HAS_TYPED_TEST	IUTEST_HAS_TYPED_TEST
 #define GTEST_HAS_TYPED_TEST_P	IUTEST_HAS_TYPED_TEST_P
 
+#define GTEST_CAN_STREAM_RESULTS_	0
+
 #define GTEST_HAS_EXCEPTIONS	IUTEST_HAS_EXCEPTIONS
 #define GTEST_HAS_RTTI			IUTEST_HAS_RTTI
 #define GTEST_HAS_SEH			IUTEST_HAS_SEH
@@ -71,6 +75,7 @@
 #include "switch/iutest_switch_expect.hpp"
 #include "switch/iutest_switch_inform.hpp"
 
+#include "switch/iutest_switch_assertion_return.hpp"
 #include "switch/iutest_switch_eq_collections.hpp"
 #include "switch/iutest_switch_package.hpp"
 #include "switch/iutest_switch_peep.hpp"
@@ -183,8 +188,8 @@ namespace tr1
 #undef IUTEST_HAS_SPI_LAMBDA_SUPPORT
 #undef IUTEST_HAS_GENRAND
 #undef IUTEST_HAS_PRINT_TO
-#undef IUTEST_HAS_ASSERTION_RETURN
 #undef IUTEST_HAS_TESTNAME_ALIAS
+#undef IUTEST_HAS_STREAM_RESULT
 
 #undef IUTEST_HAS_VARIADIC_TEMPLATES
 #undef IUTEST_HAS_VARIADIC_TEMPLATE_TEMPLATES
@@ -215,8 +220,8 @@ namespace tr1
 #define IUTEST_HAS_SPI_LAMBDA_SUPPORT	0
 #define IUTEST_HAS_GENRAND				0
 #define IUTEST_HAS_PRINT_TO				1
-#define IUTEST_HAS_ASSERTION_RETURN		0
 #define IUTEST_HAS_TESTNAME_ALIAS		0
+#define IUTEST_HAS_STREAM_RESULT		0
 
 #define IUTEST_HAS_EXCEPTIONS		GTEST_HAS_EXCEPTIONS
 #define IUTEST_HAS_RTTI				GTEST_HAS_RTTI
@@ -229,6 +234,7 @@ namespace tr1
 #include "switch/iutest_switch_expect.hpp"
 #include "switch/iutest_switch_inform.hpp"
 
+#include "switch/iutest_switch_assertion_return.hpp"
 #include "switch/iutest_switch_eq_collections.hpp"
 #include "switch/iutest_switch_package.hpp"
 #include "switch/iutest_switch_peep.hpp"
