@@ -22,10 +22,10 @@
 
 //======================================================================
 // define
-#define	IUTEST_VER			0x01060000u	//!< iutest version 1.6.0.0
+#define	IUTEST_VER			0x01060100u	//!< iutest version 1.6.1.0
 #define IUTEST_MAJORVER		0x01u		//!< Major Version
 #define IUTEST_MINORVER		0x06u		//!< Minor Version
-#define IUTEST_BUILD		0x00u		//!< Build
+#define IUTEST_BUILD		0x01u		//!< Build
 #define IUTEST_REVISION		0x00u		//!< Revision
 
 /**
@@ -95,6 +95,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * @page	CHANGELOG		ύX
  * @par		Changes
  <ul>
+  <li>v1.6.1.0
+    <ul>
+      <li>Visual Studio 2013 Preview Ή</li>
+    </ul>
+  </li>
   <li>v1.6.0.0
     <ul>
       <li>stream result Ή</li>
